.. jupyterlab_server documentation master file, created by
   sphinx-quickstart on Tue Mar 30 03:25:58 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to JupyterLab Server's documentation!
=============================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   changelog
   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
